% Template class for CEPCDoc document based On ATLAS note templates:
% 2009-03-27 Marco Delmastro <Marco.Delmastro@cern.ch>
% 2015-03-01 modified for ATLAS Phase-II Scoping Document (FL: <Francesco.Lanni@cern.ch>)
% ---
% 2015-03-09 modified for ATLAS HGTD Phase-II Trigger and Readout Requirements (FL: <Francesco.Lanni@cern.ch>)
% ---
% 2020-04-30 adapted for ATLAS HGTD Phase-II Upgrade Project Requirements (JG: <Joao.Guimaraes@cern.ch>)
% ---
\ProvidesClass{CEPCDoc}[2020/04/30 version 0.1 CEPC Project]
\NeedsTeXFormat{LaTeX2e}
\let\if@CoverPage\iffalse
\let\if@Draft\iftrue
\let\if@Note\iftrue

\DeclareOption{coverpage}{\let\if@CoverPage\iftrue}
\DeclareOption{nodraft}{\let\if@Draft\iffalse}
\DeclareOption{note}{\let\if@Note\iftrue}
\DeclareOption{book}{\let\if@Note\iffalse}

\let\if@usetikz\iffalse
\DeclareOption{usetikz}{\let\if@usetikz\iftrue}
\if@CoverPage \RequirePackage[clearpage,atlasnote]{atlascover}[2009/11/17] \fi
\ProcessOptions \relax
\LoadClass[titlepage,a4paper,11pt]{report}

%------------------------------------------------------------------------------------------
\RequirePackage{currfile}
\typeout{ ==== Processing \currfilename\ in \currfilepath\ === }
\typeout{ ====> Importing packge xkeyval}

%------------------------------------------------------------------------------------------
\RequirePackage{color,colortbl}
\RequirePackage[usenames,x11names,dvipsnames,table]{xcolor}
\PassOptionsToPackage{usenames,x11names,dvipsnames,table}{xcolor}
\RequirePackage{calc}
\RequirePackage{geometry}
\geometry{
  a4paper,%
  textwidth=16cm,% 
  textheight=23.2cm,%
  marginparsep=7pt,% 
  marginparwidth=2.5cm,%
  vcentering=true,%
  %twoside=true,% This offsets Right/Left page margins... To be checked With the other package...
  driver=pdftex%
}

\RequirePackage{subfigure}
\RequirePackage[subfigure,titles]{tocloft}
\PassOptionsToPackage{subfigure,titles}{tocloft}
\RequirePackage{framed}
% Upright greek letters
\RequirePackage{upgreek}
\RequirePackage{graphicx}
\RequirePackage{adjustbox}
\RequirePackage{mathptmx}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage[varg]{txfonts}
\RequirePackage[T1]{fontenc}
\RequirePackage[scaled]{helvet}
\RequirePackage{array}
\RequirePackage{tabularx}
\RequirePackage{tabulary}
\RequirePackage{diagbox}
%\RequirePackage{makecell}
\RequirePackage{float}
\RequirePackage{morefloats}
\RequirePackage{mathrsfs}
\RequirePackage{newclude}
\RequirePackage{enumerate}
\RequirePackage{rotating}
\RequirePackage{mathptmx}
%\RequirePackage{subfigure}

\RequirePackage{caption}
\PassOptionsToPackage{font=small,labelfont=bf, singlelinecheck=false}{caption}
\RequirePackage{multirow}
\RequirePackage{booktabs}
\RequirePackage{maybemath}
\ifpdf
  \RequirePackage{pdfcol}
  \RequirePackage[pdftex,backref=page]{hyperref}
  \PassOptionsToPackage{pdftex,backref=page}{hyperref}
  \@ifpackagelater{hyperref}{2011/12/31}{%
    \hypersetup{%
      plainpages=false,
      pdfpagelabels=true,
      bookmarks=true,
      bookmarksnumbered=true,
      bookmarksopen=true,
      bookmarksopenlevel=1,
      bookmarkstype=toc,
      linktocpage=true,
      colorlinks=true,
      allcolors=blue,
      pdfpagemode=UseOutlines,
      pdfinfo={Title={}},
      pdfborderstyle={/S/U/W 1}
     }}{}
\else
  \RequirePackage[pagebackref=page]{hyperref}
  \PassOptionsToPackage{backref=page}{hyperref}
  \@ifpackagelater{hyperref}{2012/05/13}{%
    \hypersetup{%
      bookmarks=true,
      bookmarksnumbered=true,
      bookmarksopen=true,
      bookmarksopenlevel=1,
      bookmarkstype=toc,
      linktocpage=true,
      colorlinks=true,
      allcolors=blue,
     }}{}
\fi

\RequirePackage{ifthen}
\RequirePackage{xstring}
\RequirePackage{pageslts}
\RequirePackage{fancyhdr}
\RequirePackage{pdfpages}

\RequirePackage{cite}
\RequirePackage{lineno}   % This is provided with the package

\RequirePackage{animate}
\RequirePackage{colortbl}
\RequirePackage{xspace}
\RequirePackage[italic]{hepparticles}
\RequirePackage[italic]{hepnames}

\RequirePackage{pifont}
\RequirePackage{longtable}
\RequirePackage{tabu}
\RequirePackage{booktabs}
\RequirePackage{stackengine}
\RequirePackage{pdflscape}
%\RequirePackage{floatrow}
\RequirePackage{threeparttablex}
\RequirePackage{chngcntr}

%\RequirePackage{ifthen}
\RequirePackage{xstring}
% This Is hugly... but titlesec defines them...
\global\let\headrule\relax
\global\let\footrule\relax
\typeout{Importing fancyhdr}
\RequirePackage{fancyhdr}
\RequirePackage{hhline}

% This is hugly... Need to define \thepage otherwise the lastpackage complains...
% Can't understand why it is not already defined....
\typeout{Defining Command \\thepage}
\providecommand{\thepage}{}
\typeout{Importing pageslts}
\RequirePackage{pageslts}

% Glossary
\typeout{ ===> Loading glossaries packages}
\RequirePackage{glossaries}
\PassOptionsToPackage{nopostdot=true,xindy={language=english,codepage=utf8},nonumberlist,style=altlist,nogroupdisk,acronym,toc,shortcuts}{glossaries}
\newcommand*{\glsgobblenumber}[1]{}
\newcommand*{\glsaddnp}[2][]{%
  \glsdoifexists{#2}%
  {%
%     \def\@glsnumberformat{glsnumberformat}% DELETED
    \def\@glsnumberformat{glsgobblenumber}% NEW
    \edef\@gls@counter{\csname glo@#2@counter\endcsname}%
    \setkeys{glossadd}{#1}%
    \@gls@saveentrycounter
    \@do@wrglossary{#2}%
  }%
}
%% new code; modified \glsaddall
\renewcommand{\glsaddallunused}[1][]{%
  \edef\@glo@type{\@glo@types}%
  \setkeys{glossadd}{#1}%
  \forallglsentries[\@glo@type]{\@glo@entry}{%
    \ifglsused{\@glo@entry}{}{%
     \glsaddnp[#1]{\@glo@entry}}}%
}

\RequirePackage{footnote}
\RequirePackage{tablefootnote}
\RequirePackage{scrextend}
\RequirePackage{xparse}
\RequirePackage{enumitem}
\RequirePackage{fancybox}
\RequirePackage{tcolorbox}
\RequirePackage{chngcntr}
\RequirePackage{attachfile}
\RequirePackage[pagestyles,explicit,newparttoc]{titlesec}
\RequirePackage{titletoc}
\RequirePackage{etoolbox}
\RequirePackage{appendix}
\PassOptionsToPackage{toc,page}{appendix}

\RequirePackage{cleveref}
\PassOptionsToPackage{noabbrev,nameinlink}{cleveref}

\PassOptionsToPackage{tablegrid,hideauthorcolumn,nochapter,tocentry}{vhistory}
\RequirePackage{vhistory}
\typeout{ ===> Revision history package: \vh@tablegrid }

% This Is fundamental otherwise you will Get Error Like \newrite 
\RequirePackage{morewrites}
%------------------------------------------------------------------------------------------
\typeout{ ===> Redefining partname As chapter}
\if@Note
\else
 \newcommand{\chapter}{\part}
 \renewcommand{\partname}{Chapter}
 \typeout{ ===> Redefining content style of part,section And subsections through titlecontents}
 \titlecontents{part}[6pc]
     {\addvspace{1.5pc}\Large\bfseries\filright}%
     {\contentslabel[\hspace*{-6pc}\textsc{\partname\;\thecontentslabel~:}]{0pc}\\*[.2pc]%
       \hspace*{-6pc}\Large}  % with numbering
     {\contentslabel[\hspace*{-6pc}\partname\;:]{0pc}\\*[.2pc]%
       \hspace*{-6pc}\Large}  % without numbering
     {\hspace*{-6pc}\titlerule*[2pt]{}\contentspage}              % filler
     [\addvspace{0.1pc}]
\fi
    
\titlecontents{section}[3.em] % 
    {\vspace{0.5pc}\large\bfseries}
    {\large\bfseries~\contentslabel{3.em}}
    {\hspace*{-3.em}\large\bfseries~\contentslabel{3.em}}
    {\large\bfseries~\titlerule*[1pc]{.}\contentspage}
\titlecontents{subsection}[4.6em] % ie, 
    {}
    {~\contentslabel{3.8em}}
    {\hspace*{-3.8em}}
    {~\titlerule*[1pc]{.}\contentspage}
\titlecontents{subsubsection}[6.9em] % ie, 4.6em (subsection) + 2.3em
    {}
    {~\contentslabel{5.3em}}
    {\hspace*{-5.3em}}
    {~\titlerule*[1pc]{.}\contentspage}

\titleclass{\subsubsubsection}{straight}[\subsection]
    
\titlecontents{subsubsubsection}[8.1em] % ie, 4.6em (subsection) + 2.3em (subsubsection) + 1.2em
    {}
    {~\contentslabel{6.5em}}
    {\hspace*{-6.5em}}
    {~\titlerule*[1pc]{.}\contentspage}
    
\typeout{ ===> Redefining format of part,section And subsections through titleformat}
\titleformat{\part}[frame]
 {\vspace{0.45\textheight}\normalfont}
 {\filright\footnotesize\enspace \partname\enspace\thepart\enspace} %Part \thepart\enspace}
 {8pt} {\Huge\bfseries\filcenter #1} 
\titleformat{\section}
 {\normalfont\LARGE\bfseries}{\thesection}{1em}{#1}
\titleformat{\subsection}
 {\normalfont\Large\bfseries}{\thesubsection}{1em}{#1}
\titleformat{\subsubsection}
 {\normalfont\normalsize\bfseries}{\thesubsubsection}{1em}{#1}
\titleformat{\subsubsubsection}
 {\normalfont\normalsize\bfseries}{\thesubsubsubsection}{1em}{#1}
\titlespacing*{\subsubsubsection}
 {0pt}{3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex}

\titleformat{\paragraph}[runin]
 {\normalfont\normalsize\bfseries}{\theparagraph}{1em}{#1}
\titleformat{\subparagraph}[runin]
 {\normalfont\normalsize\bfseries}{\thesubparagraph}{1em}{#1}

\typeout{ ===> Redefining part And partitle commands And their options}
\let\titlesec@part\part
\renewcommand{\part}{\@ifstar\part@star\part@nostar}
\def\part@star#1{\NR@gettitle{#1}\titlesec@part*{#1}\renewcommand{\parttitle}{#1}}
\def\part@nostar{\@ifnextchar[\part@nostar@opt\part@nostar@nopt}
\def\part@nostar@nopt#1{\NR@gettitle{#1}\titlesec@part{#1}\renewcommand{\parttitle}{#1}}
\def\part@nostar@opt[#1]#2{\NR@gettitle{#2}\titlesec@part[#1]{#2}\renewcommand{\parttitle}{#2}}

\typeout{ ===> Redefining section And Sub(Sub)-sections counters}
\ifx\c@section\undefined
   \newcounter {section}[part]
\else
   \let\c@section\@undefined
   \let\c@subsection\@undefined
   \let\c@subsection\@undefined
   \let\c@subsubsection\@undefined
   \let\c@subsubsubsection\@undefined
   \let\c@paragraph\@undefined
   \let\c@subparagraph\@undefined
   \newcounter {section}[part]
   \newcounter {subsection}[section]
   \newcounter {subsubsection}[subsection]
   \newcounter {subsubsubsection}[subsubsection]
   \newcounter {paragraph}[subsubsubsection]
   \newcounter {subparagraph}[paragraph]
\fi

\if@Note
 \renewcommand*\thesection{\arabic{section}}
 \renewcommand*\thesubsection{\thesection.\arabic{subsection}}
 \renewcommand*\thesubsubsection{\thesubsection.\arabic{subsubsection}}
 \renewcommand*\thesubsubsubsection{\thesubsubsection.\arabic{subsubsubsection}}
 \renewcommand*\theparagraph{\thesubsubsubsection.\arabic{paragraph}}
 \renewcommand*\thefigure{\arabic{figure}}
 \renewcommand*\thetable{\arabic{table}}
\else
 \renewcommand*\thesection{\thepart.\arabic{section}}
 \renewcommand*\thesubsection{\thepart.\arabic{section}.\arabic{subsection}}
 \renewcommand*\thesubsubsection{\thepart.\arabic{section}.\arabic{subsection}.\arabic{subsubsection}}
 \renewcommand*\thesubsubsubsection{\thepar.\arabic{section}.\arabic{subsection}.\arabic{subsubsection}.\arabic{subsubsubsection}}
 \renewcommand*\theparagraph{\thepart.\arabic{section}.\arabic{subsection}.\arabic{subsubsection}.\arabic{paragraph}}
 \renewcommand*\thefigure{\thepart.\arabic{figure}}
 \renewcommand*\thetable{\thepart.\arabic{table}}
\fi

\typeout{ ===> Defining commands strTruncate And splitheader}
\providecommand{\strTruncate}[2]{}
\renewcommand{\strTruncate}[2]{%
  \StrLen{#1}[\mystrlen]
  \ifthenelse{\mystrlen > #2}{\StrLeft{#1}{#2}\ldots}{#1}
}

\DeclareRobustCommand\splitheader[2]{#1 #2}
\def\contsplitheader{}
\def\dosplitheader{%
\gdef\contsplitheader{}%
\DeclareRobustCommand\splitheader[2]{##1\gdef\contsplitheader{##2}}}

\typeout{ ===> Defining commands frontmatter, mainmatter,backmatter}
\newcommand\frontmatter{
  \pagenumbering{roman}
  \pagestyle{CEPCDocToc}
}

\newcommand{\mainmatter}{
  \pagenumbering{arabic}
  \pagestyle{CEPCDoc}
  \captionsetup[figure]{labelfont=bf, textfont=sf, justification=justified, singlelinecheck=true}
  \captionsetup[table]{labelfont=bf, textfont=sf, justification=justified, singlelinecheck=false}
  \if@Note
  \else
       \counterwithin{figure}{part}
       \counterwithin{table}{part}
  \fi
}

\newcommand\backmatter{%
 \newcounter{partApp}
 \pagestyle{CEPCDocApp}
 \captionsetup[figure]{labelfont=bf, textfont=rm, justification=justified, singlelinecheck=true}
 \captionsetup[table]{labelfont=bf, textfont=sf, justification=justified, singlelinecheck=false}
 \counterwithin{figure}{part}
 \counterwithin{table}{part}
 \pretocmd{\chapter}{%
%   \clear@ppage
   \@resets@pp  % <--- This seems fondamental Or the appendices will Not bookmarked in the PDF (weird!!)
   \renewcommand{\thesection}{\thechapter.\arabic{section}} % <--- This Is needed here because of the definition of \@reset@pp
   \stepcounter{partApp}%
   \setcounter{page}{1}
 }{}{}
 \apptocmd{\@part}{%
   \clear@ppage%
 }{}{}
}


\typeout{ ===> Defining pagestyle CEPCDoc }
\newpagestyle{CEPCDoc}[\footnotesize\sffamily\slshape]{
 \pagenumbering{arabic}
 \setheadrule{0.4pt}
 \setfootrule{0.4pt}
 \sethead%
        [\hspace{-0.2cm}\slshape % % even pages
	{\begin{tabular}[b]{l@{}}
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
               \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	     \fi}
	    \end{tabular}}	
	]%
	[]%
	[{\begin{tabular}[b]{r@{}}
	    {\ifx\@doctitle\@empty\mbox{}%
	     \else
	       \@doctitle
	     \fi}
	    \end{tabular}}
	]%
        {\hspace{-0.2cm}\slshape % odd pages
	   {\begin{tabular}[b]{l@{}}
	    \footnotesize \@doctitle
	    \end{tabular}} }
	{}
	{\begin{tabular}[b]{r@{}}
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
               \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	     \fi}
	    \end{tabular}} 

 \setfoot%
         [Page {\textbf{\thepage}} ~ of ~\lastpageref{pg:lastpage}]%
         []%
	 [ \ifthenelse{\equal{\thepart}{}}{}{\footnotesize\slshape% 
	       ~\thepart: \strTruncate{\parttitle}{20} } ]%
	 { \ifthenelse{\equal{\thepart}{}}{}{\footnotesize\slshape%
	       ~\thepart: \strTruncate{\parttitle}{20} } }%
	 {}%
	 {Page {\textbf{\thepage}} ~ of ~\lastpageref{pg:lastpage}} %odd
}%end pagestyle 

\typeout{ ===> Defining pagestyle CEPCDocNoLabelHead }
\newpagestyle{CEPCDocNoLabelHead}[\footnotesize\sffamily\slshape]{
 \pagenumbering{arabic}
 \setheadrule{0.4pt}
 \setfootrule{0.4pt}
 \sethead%
         [][]%
	 [\footnotesize \slshape \sectiontitle]%
	 {}{}%
	 {\footnotesize \slshape \sectiontitle}
 \setfoot%
         [Page {\textbf{\thepage}} ~ of ~\pageref{LastPages}]%
         []%
	 [\footnotesize {\slshape \@doctitle ~
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
              \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	      \fi}
	 }]%
	 {\footnotesize {\slshape \@doctitle ~
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
              \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	      \fi}
	 }}%
	 {}%
	 {\Page {\textbf{\thepage}} ~ of ~\lastpageref{pg:lastpage}} %odd
}%end pagestyle 



\typeout{ ===> Defining pagestyle CEPCDocApp }
\newpagestyle{CEPCDocApp}[\footnotesize\sffamily\slshape]{
 \pagenumbering{arabic}
 \renewcommand*{\thepage}{\Alph{partApp}--\arabic{page}}
 \renewcommand*{\thepart}{\Alph{partApp}}
 \providecommand*{\thechapter}{\thepart}
 \renewcommand\appendixname{Appendix}
 \renewcommand\partname{\appendixname}
 \renewcommand*{\thesection}{\thechapter.\arabic{section}}
% \renewcommand*{\thesection}{\thechapter.\@arabic\c@section}
 \renewcommand*{\thesubsection}{\thesection.\@arabic\c@subsection}
 \renewcommand*{\thesubsubsection}{\thesubsection.\@arabic\c@subsubsection}
 \renewcommand\theparagraph    {\thesubsubsection.\@arabic\c@paragraph}
 \renewcommand\thesubparagraph {\theparagraph.\@arabic\c@subparagraph}
 \renewcommand*{\setthesection}{\thesection}
 \renewcommand*{\setthesubsection}{\thesubsection}
 \setheadrule{0.4pt}
 \setfootrule{0.4pt}
 \sethead%
        [\hspace{-0.2cm}\slshape % % even pages
	   {\begin{tabular}[b]{l@{}}
	     \footnotesize {\slshape \@doctitle } \\
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
               \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	     \fi}
	    \end{tabular}}	
	]%
	[]%
	[{\begin{tabular}[b]{r@{}}
	    ATLAS CEPC \\ HL-LHC Upgrade Project
	    \end{tabular}}]%
        {\hspace{-0.2cm}\slshape % odd pages
	   {\begin{tabular}[b]{l@{}}
	    ATLAS CEPC \\ HL-LHC Upgrade Project
	    \end{tabular}} }
	{}
	{\begin{tabular}[b]{r@{}}
	     \footnotesize {\slshape \@doctitle } \\
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
               \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	     \fi}
	    \end{tabular}} 
 \setfoot[\hspace{-0.05cm}\textbf{\thepage}][][Appendix~\thepart: \parttitle]%
         {\hspace{-0.05cm}Appendix~\thepart: \parttitle}{}{\textbf{\thepage}}

 \titlecontents{part}[8pc]%
    {\addvspace{1.5pc}\Large\bfseries\filright}%
    {\contentslabel[\hspace*{-8pc}\textsc{\appendixname\,\thecontentslabel\,:}]{0pc}}%
    {\contentslabel[\hspace*{-8pc}\textsc{\appendixname\,:}]{0pc}}%\hspace*{-6pc}\contentslabel[\appendixname\,\thecontentslabel\,:]{1pc}}%
    {~\titlerule*[1pc]{}\contentspage}%
    [\addvspace{2pt}]%
    
% \titlecontents{section}[3.em] % 
%    {\vspace{0.5pc}\large\bfseries}
%    {\hspace*{-3.em}~\contentslabel{3.em}}
%    {\hspace*{-3.em}~\contentslabel{3.em}}
%    {~\titlerule*[1pc]{.}\contentspage}

}

\typeout{ ===> Defining pagestyle CEPCDocToc }
\newpagestyle{CEPCDocToc}[\footnotesize\sffamily\slshape]{
  \pagenumbering{roman}
  \setheadrule{0.4pt}
  \setfootrule{0.4pt}
  \sethead%
	[\hspace{-0.2cm}% even pages
	  {\begin{tabular}[b]{l@{}}
	     \footnotesize {\slshape KAKKA \@doctitle } \\
	    \end{tabular}} ]
	[]%
        [~{\begin{tabular}[b]{r@{}}%
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
               \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	     \fi}
	  \end{tabular}}]%
	{\begin{tabular}[b]{r@{}}
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
               \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	     \fi}
	     \end{tabular}}
	{}
	{\hspace{-0.2cm}\slshape
	 \begin{tabular}[b]{l@{}}
	    \end{tabular}} 

	\setfoot[\hspace{-0.05cm}\thepage][][]{}{}{\thepage}
}

\typeout{ ===> Defining pagestyle CEPCDocBiblio }
\newpagestyle{CEPCDocBiblio}[\footnotesize\sffamily\slshape]{
  \setheadrule{0.4pt}
  \setfootrule{0.4pt}
  \sethead%
	[\hspace{-0.2cm}% even pages
	   {\begin{tabular}[b]{l@{}}
	 CEPC Project  \\
	     {\ifx\@lastModifiedDate\@empty\mbox{}%
	     \else 
               \@lastModifiedDate
	     \fi}
	     {\ifx\@draftversion\@empty\mbox{}%
	     \else 
              \;- Version \@draftversion 
	     \fi}
	    \end{tabular}} ]
	[]
        [{\begin{tabular}[b]{r@{}}
	   CEPC Project
	  \end{tabular}} ]
	{\hspace{-0.2cm}\slshape
	   {\begin{tabular}[b]{l@{}}
	    CEPC Project
	    \end{tabular}} }
	{}
	{\begin{tabular}[b]{r@{}}
	     \footnotesize {\slshape \@doctitle } \\
	  {\ifx\@lastModifiedDate\@empty\mbox{}%
	   \else 
           \@lastModifiedDate
	   \fi}
	  {\ifx\@draftversion\@empty\mbox{}%
	   \else 
           \;- Version \@draftversion 
	   \fi}
	  \end{tabular}}%
    \setfoot[\hspace{-0.05cm}Page \textbf{\thepage}~of~\lastpageref{pg:lastpage}][][]{}{}{Page \textbf{\thepage}~of~\lastpageref{pg:lastpage}} %odd
    \titlecontents{part}[0.0em]
       {\vspace{1.5pc}\Large\bfseries}
       {\Large\bfseries~\thecontentslabel.}
       {\Large\bfseries}
       {\Large\bfseries~\titlerule*[1pc]{ }\contentspage}

}

\typeout{ ===> Redefining contentsname And tableofcontents }
\renewcommand\contentsname{{\fontsize{28}{32}\selectfont Contents}}
\renewcommand\tableofcontents{%
    \@starttoc{toc}%
}
\renewcommand\bibname{References}

\newcommand{\myline}{\specialrule{0.5pt}{1.pt}{1.pt}\specialrule{0.5pt}{1.pt}{1.pt}}

\def\@CEPCDocTwiki{}
\newcommand{\CEPCDocTwiki}[1]%
{
  \def\@CEPCDocTwiki{#1}
}
\def\@DocAuthors{}
\newcommand{\DocAuthors}[1]%
{
  \def\@DocAuthors{#1}
}
\def\@DocCheckedBy{}
\newcommand{\DocCheckedBy}[1]%
{
  \def\@DocCheckedBy{#1}
}
\def\@DocApprovedBy{}
\newcommand{\DocApprovedBy}[1]%
{
  \def\@DocApprovedBy{#1}
}

\def\@EDMSDocUrl{}
\newcommand{\EDMSDocUrl}[1]%
{
  \def\@EDMSDocUrl{#1}
}
\def\@EDMSDocNo{}
\newcommand{\EDMSDocNo}[1]%
{
  \def\@EDMSDocNo{#1}
}
\def\@EDMSDocId{}
\newcommand{\EDMSDocId}[1]%
{
  \def\@EDMSDocId{#1}
}

\newcommand{\AtlasCopyrightFooter}{%
\parbox[b]{\linewidth}{%
  \footnotesize\textit{ \copyright\ \the\year \ CERN for the benefit of the ATLAS Collaboration.
  \newline
  Reproduction of this article or parts of it is allowed As
  specified in the CC-BY-4.0 license.
  }}\par
}

\newcommand{\myred}{red}
\newcommand{\editnotecolor}{\myred}
\DeclareRobustCommand{\editnote}[2][\defaulteditor]{\textcolor{\editnotecolor}{\textit{[{\textbf{{#1}}: }{{#2}}]}}}
\DeclareRobustCommand{\defaulteditor}{Roger Federer}

\typeout{ ===> Defining maketitlepage }
\newcommand{\maketitlepage}{%
   \begin{titlepage}
%  \null
%  \ifx\@draftversion\@empty\mbox{}%
%  \else {\flushright{ \@lastModifiedDate \\
%         Version \@draftversion \\}
%        } 
%  \fi
%\begin{tabular}{p{0.6\textwidth}p{0.4\textwidth}}
\begin{figure}[!htbp]
  \begin{minipage}{0.7\textwidth}
    \raggedright
     {\small ATLAS CEPC \PhaseTwo Upgrade Project}  
   \end{minipage}
   \hfill
   \begin{minipage}{0.3\textwidth}
     \raggedleft
     {\small EDMS Doc.: \@EDMSDocNo} 
     {\small EDMS Id: \@EDMSDocId} 
   \end{minipage}
\end{figure}
%\\
%\end{tabular}
  \hfill
    \begin{figure}[!htbp]
     \centering
     \begin{minipage}{0.2\textwidth}
         \raggedright
         \includegraphics[width=0.83\textwidth]{Logos/AT_atlaslogo_2015} 
     \end{minipage}%
     \hfill
     \begin{minipage}{0.6\textwidth}
      
      \end{minipage}%
     \hfill    
     \begin{minipage}{0.2\textwidth}
         \raggedleft
         \includegraphics[width=0.83\textwidth]{Logos/AT_cernlogo} 
%         \caption*{{\normalfont{Draft version \draftversion}}}
     \end{minipage}
   \end{figure}
%   \vskip \AN@skipbeforetitle
   \begin{center}%
    {\Huge \@doctitle }
    \end{center}\par
    \vspace*{0.5cm}
    \begin{center}
    \textbf{Abstract}
    \end{center}
    \input{\@abstractFile}
   \\   
   \vfill
   {\flushleft
   \begin{tabular}[bhp]{|p{0.4\textwidth}|p{0.3\textwidth}|p{0.3\textwidth}|}
   \hline
   \multicolumn{3}{|l|}{\bf ATLAS CEPC \PhaseTwo Upgrade Project}  \\
   \hline
   \multicolumn{1}{|l}{ATLAS  Doc:}  & \multicolumn{1}{l}{\@EDMSDocNo} & \\
   \multicolumn{1}{|l}{EDMS Id:}  & \multicolumn{1}{l}{\@EDMSDocId} & \\
   \multicolumn{1}{|l}{EDMS Url:}  & \multicolumn{2}{l|}{\url{\@EDMSDocUrl}}  \\
   \hline
   \multicolumn{1}{|l}{Version:}  & \multicolumn{1}{l}{\@draftversion} & \\
   \multicolumn{1}{|l}{Created:} &    \multicolumn{1}{l}{\@creationDate} & \\
   \multicolumn{1}{|l}{Last modified:} &    \multicolumn{1}{l}{\@lastModifiedDate} & \\
   \myline
   \textbf{Prepared by:} &  \textbf{Checked by:} &  \textbf{Approved by:}\\ 
      & & \\
  \begin{minipage}{0.4\textwidth}
     \@DocAuthors
  \end{minipage}
    & 
  \begin{minipage}{0.3\textwidth} 
     \@DocCheckedBy
  \end{minipage}   
  & 
  \begin{minipage}{0.3\textwidth} 
  \@DocApprovedBy
  \end{minipage}   
   \\
   &  & \\
   & & \\
   &  & \\
   \hline
   \end{tabular}}
   \\
  \AtlasCopyrightFooter\hfill
  \end{titlepage}
  \thispagestyle{empty}
   \begin{center} \vspace*{\stretch{1}}[INTENTIONALLY BLANK PAGE]\vspace*{\stretch{1}} \end{center}
      \clearpage
      \setcounter{page}{3}
      \setcounter{table}{0}
  } 
% This some before-and-after code that surrounds the title page. It
% shouldn't need to be modified. I've pulled out the part the actually
% typesets the title page and placed it in the \maketitlepage command
% above.

\typeout{ ===> Redefining Command maketitle }
\renewcommand\maketitle{%
  \pagenumbering{roman}
  \thispagestyle{empty}
  \maketitlepage%
  %\end{titlepage}%
  \setcounter{footnote}{0}%
  \setcounter{page}{3}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@\DocAuthors\@empty
  \global\let\@DocCheckedBy\@empty
  \global\let\@DocApprovedBy\@empty
  \global\let\@date\@empty
  \global\let\@doctitle\@empty
  \global\let\doctitle\relax
  \global\let\date\relax
  \global\let\and\relax
}

\typeout{ ===> Defining icaption command }
% Use \icaption instead of \caption in tables and figures to get a
% caption that is indented. Note that the label should be included
% inside \icaption for it to work properly.
\newlength{\capindent}
\setlength{\capindent}{0.5cm}
\newlength{\capwidth}
\setlength{\capwidth}{\textwidth}
\addtolength{\capwidth}{-2\capindent}
\newlength{\figwidth}
\setlength{\figwidth}{\textwidth}
\addtolength{\figwidth}{-2.0cm}
\newcommand{\icaption}[2][!*!,!]{\hspace*{\capindent}%
  \begin{minipage}{\capwidth}
    \ifthenelse{\equal{#1}{!*!,!}}%
      {\caption{#2}}%
      {\caption[#1]{#2}}
      \vspace*{3mm}
  \end{minipage}}


\typeout{ ===> Defining Enum/itemize_dense environments With smaller spaces }
\newenvironment{enum_dense}
{
 \begin{enumerate}
    \setlength{\itemsep}{1pt}
    \setlength{\parskip}{0pt}
    \setlength{\parsep}{0pt}
}{\end{enumerate}}
%
\newenvironment{item_dense}
{
\begin{itemize}
   \setlength{\itemsep}{1pt}
   \setlength{\parskip}{0pt}
   \setlength{\parsep}{0pt}
}{\end{itemize}}

\typeout{ ===> Defining default fonts Arial }
\renewcommand{\rmdefault}{phv} % Arial
%\renewcommand{\sfdefault}{phv} % Arial


\typeout{ ===> Specify counters For section And toc depth }
\setcounter{secnumdepth}{6}
\setcounter{tocdepth}{4}

\typeout{ ===> Redefining commands For labelenum...i...iv }
\renewcommand{\labelenumi}{\arabic{enumi}. }
\renewcommand{\labelenumii}{\arabic{enumi}.\arabic{enumii} }
\renewcommand{\labelenumiii}{\arabic{enumi}.\arabic{enumii}.\arabic{enumiii} }
\renewcommand{\labelenumiv}{\arabic{enumi}.\arabic{enumii}.\arabic{enumiii}.\arabic{enumiv} }

\typeout{ ===> Defining commands creationDate And lastModifiedDate }
\def\@creationDate{}
\newcommand{\creationDate}[1]%
{
  \def\@creationDate{#1}
}
\def\@lastModifiedDate{}
\newcommand{\lastModifiedDate}[1]%
{
  \def\@lastModifiedDate{#1}
}

% Defaults for title page
\newdimen\AN@skipbeforetitle
\AN@skipbeforetitle=60\p@
\newcommand\skipbeforetitle[1]{
  \AN@skipbeforetitle=#1
}


\def\@doctitle{%
Generic CEPC Document
}
\newcommand{\doctitle}[1]%
{
 \def\@doctitle{#1}
}
\def\@date{\today}

% Draft version 
\def\@draftversion{}
\newcommand{\draftversion}[1]%
{
  \def\@draftversion{#1}
}

\def\@abstractFile{}
\newcommand{\abstractFile}[1]%
{
  \def\@abstractFile{#1}
}


%------------------------------------------------------------------------------------------------
\typeout{ ====> Definition of Column/Row Type in Table environments}
\newcommand*{\@rowstyle}{}
\ifdefined\rowstyle
\renewcommand*{\rowstyle}[1]{% sets the style of the next row
  \gdef\@rowstyle{#1}%
  \@rowstyle\ignorespaces%
}
\else
\newcommand*{\rowstyle}[1]{% sets the style of the next row
  \gdef\@rowstyle{#1}%
  \@rowstyle\ignorespaces%
}
\fi
\newcolumntype{=}{% resets the row style
  >{\gdef\@rowstyle{}}%
}
\newcolumntype{+}{% adds the current row style to the next column
  >{\@rowstyle}%
}
\newcommand\CostTableHeadStyle{%
\rowcolor{NavyBlue}
\rowstyle{\bfseries\textcolor{white}}
}

%------------------------------------------------------------------------------------------
\typeout{===> Defining definition, requirement, remark and recommendation environments}

\newcommand*{\flref}[2][Eq.~]{%
  \hyperref[{#2}]{#1(\ref*{#2})}%
}
  
\tcbuselibrary{skins}

%----- Definition environment
\newcounter{definitionCounter}[section]
\setcounter{definitionCounter}{0}
\counterwithin*{definitionCounter}{section}
\newcommand{\listdefinitionname}{List of Definitions}
\newlistof[section]{definition}{lodef}{\listdefinitionname}
\renewcommand{\cftlodeftitlefont}{\Large\bfseries}
\renewcommand{\cftafterlodeftitle}{\hfill}
\cftsetindents{definition}{0.5cm}{1.25cm}
\counterwithin*{definition}{section}
\newcommand{\definitionautorefname}{Definition}
\newenvironment{definition}[1][]{%
  \refstepcounter{definitionCounter}%
  \refstepcounter{definition}%
  \addcontentsline{lodef}{definition}{\protect\numberline{\arabic{part}.\arabic{section}.\thedefinitionCounter}\xspace #1}
  \begin{tcolorbox}[before skip=0.35cm, colback=blue!10!white, colframe=MidnightBlue!75!black,%
                    title={Definition  \thedefinitionCounter: {\it#1}},fonttitle=\bfseries,%
                    title style={left color=blue!50!green!50!black,right color=yellow!50!blue},%
                    %interior style={left color=green!50!black,right color=blue!50},%
                    %title={\bf Definition \arabic{part}.\arabic{section}.\arabic{definitionCounter}},%
                    enhanced,shadow={2mm}{-1mm}{0mm}{fill=MidnightBlue,opacity=0.25}]%
    \par
}{%
  \end{tcolorbox}%
}
\renewcommand*{\thedefinition}{%
 %\arabic{part}%
 %\ifnum\value{section}=0%
 %  .%
 %\else%
  % .\arabic{section}.%
 %\fi
 \arabic{definition}%
}
\crefname{definition}{definition}{definitions}
\Crefname{definition}{Definition}{Definitions}
%\creflabelformat{definition}{#2#1#3}
\crefrangelabelformat{definition}{#3#1#4 -- #5#2#6}


%----- Requirement environment
\newcounter{ruleCounter}[section]
\setcounter{ruleCounter}{0}
\counterwithin*{ruleCounter}{section}
\newcommand{\listrequirementname}{List of Requirements}
\newlistof[section]{requirement}{loreq}{\listrequirementname}
\renewcommand{\cftloreqtitlefont}{\Large\bfseries}
\renewcommand{\cftafterloreqtitle}{\hfill}
\cftsetindents{requirement}{0.5cm}{1.25cm}
\counterwithin*{requirement}{section}
\newcommand{\requirementautorefname}{Requirement}

\newenvironment{requirement}[1][]{%
  \refstepcounter{ruleCounter}
  \refstepcounter{requirement}
%  \addcontentsline{loreq}{requirement}{\protect\numberline{\arabic{part}.\checksectionnumber\theruleCounter}\xspace #1}
  \addcontentsline{loreq}{requirement}{\protect\numberline{\therequirement}\xspace #1}
  \begin{tcolorbox}[before skip=0.35cm, colback=red!5!yellow!5!white, colframe=MidnightBlue!75!black,%
                    title={Requirement \therequirement: {\it #1}},%
                    title style={left color=blue!75!green!25!red, right color=yellow!50!blue },%
                    enhanced,shadow={2mm}{-1mm}{0mm}{fill=MidnightBlue,opacity=0.25},%
                    fonttitle=\bfseries]%
    \par%
}{%
  \end{tcolorbox}%
}

\if@Note
\renewcommand*{\therequirement}{%
 \arabic{requirement}%
}
\else
\renewcommand*{\therequirement}{%
 \arabic{part}%
 \ifnum\value{section}=0%
   .%
 \else%
   .\arabic{section}.%
 \fi
 \arabic{requirement}%
 }
\fi
 
%\renewcommand*{\therequirement}{%
%\ifthenelse{{section>0}{\arabic{part}.\arabic{section}.\arabic{requirement}}{\arabic{part}.\arabic{requirement}}}%
%}
\crefname{requirement}{requirement}{requirements}
\Crefname{requirement}{Requirement}{Requirements}
\crefrangelabelformat{requirement}{#3#1#4 -- #5#2#6}


\newcommand{\listrecommendationname}{List of Recommendations}
\newlistof{recommendation}{lorec}{\listrecommendationname}
\renewcommand{\cftlorectitlefont}{\Large\bfseries}
\renewcommand{\cftafterlorectitle}{\hfill}
\cftsetindents{recommendation}{0.5cm}{0.75cm}

\newenvironment{recommendation}[1][]{%
  \refstepcounter{recommendation}
  \addcontentsline{lorec}{recommendation}{\protect\numberline{\therecommendation}\xspace #1}
  \begin{tcolorbox}[before skip=0.35cm, colback=green!10!white,%colframe=MidnightBlue!75!black,%
                    title={{\bf Recommendation \arabic{recommendation}:} \it #1},%
                    title style={left color=blue!75!green!25!black,right color=yellow!50!blue},%
                    enhanced,shadow={2mm}{-1mm}{0mm}{fill=MidnightBlue,opacity=0.25}]%
    \par
}{%
  \end{tcolorbox}%
}

\newenvironment{remark}[1][]{%
  \begin{tcolorbox}[before skip=0.35cm, colback=gray!10!white, colframe=MidnightBlue!75!black,%
                    title={{\bf Remark:} #1},fontupper=\sffamily,%
                    title style={left color=black!20!green!50!black,right color=blue!20!black},%
                    %interior style={left color=green!50!black,right color=blue!50},%
                    %title={\bf Definition \arabic{part}.\arabic{section}.\arabic{definitionCounter}},%
                    enhanced,shadow={2mm}{-1mm}{0mm}{fill=MidnightBlue,opacity=0.25}]%
    \par
}{%
  \end{tcolorbox}%
}

\typeout{==> Define loadhistory command}
\newcommand{\loadrevhistory}[2][toc]{%
 \section*{Revision History}
 \ifx toc#1 \addcontentsline{toc}{section}{Revision History} \fi
 \include*{#2}
 \clearpage
}

%------------------------------------------------------------------------------------------------
\AtBeginDocument{
  \typeout{ ===> Execution of commands AtBeginDocument }
  \pagenumbering{roman}
  \pagestyle{CEPCDocToc}
  \if@CoverPage
    \thispagestyle{empty}
    \includepdf{Cover/FrontCover}
  \fi
  \if@Draft  
    \usepackage{draftwatermark}
    \SetWatermarkLightness{0.9}
  \fi
%  \maketitle
  \if@Draft
    \linenumbers
  \fi
  %\bookmarksetup{open,numbered}
  \newcommand{\head}[1]{\textsf{\textbf{#1}}}
%  \floatsetup[table]{capposition = top, font = sf}    % Sets table to sans serif font and puts the caption on the top
  \captionsetup[figure]{labelfont=bf, textfont=rm, justification=justified, singlelinecheck=true}
  \captionsetup[table]{labelfont=bf, textfont=sf, justification=justified, singlelinecheck=false}
  \setstackEOL{\#}
  \setstackgap{L}{12pt}
  \newcolumntype{L}[1]{>{\raggedright\arraybackslash}p{#1}}
  \newcolumntype{C}[1]{>{\centering\arraybackslash}p{#1}}

  \renewcommand{\TPTtagStyle}{\sf\it}
  \def\fltnoteshort#1{\protect\TPToverlap{\textsuperscript{{\TPTtagStyle #1}}}}
  \def\fltnote#1{\protect\TPToverlap{\textsuperscript{{\TPTtagStyle see Note #1}}}}
  \def\fltnotes#1{\protect\TPToverlap{\textsuperscript{{\TPTtagStyle see Notes #1}}}}
  \g@addto@macro\TPT@defaults{\footnotesize} 
  \renewcommand{\TPTdoTablenotes}{%
    \list{}{\topsep 1pt  \partopsep 1pt \head{Notes: }\hfil%
    \itemsep 2pt \parsep 2pt \itemindent 3pt
    \TPTnoteSettings
    \let\makelabel\TPTnoteLabel%
  }}
  
  %\pagenumbering{arabic} % reset page numbering after title page
}

\AtEndDocument{
  \typeout{ ===> Execution of commands AtEndDocument }
  \if@CoverPage
     \thispagestyle{empty}
     \includepdf{Cover/BackCover}
  \fi
}
% That's all, folks!
\endinput

